--[[
Copyright 2010-2012 João Cardoso
Scrap Cleaner is distributed under the terms of the GNU General Public License (or the Lesser GPL).
This file is part of Scrap Cleaner.

Scrap Cleaner is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Scrap Cleaner is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Scrap Cleaner. If not, see <http://www.gnu.org/licenses/>.
--]]

local TimerFrame = CreateFrame('Frame')
local NextTime = 0

local function CleanTrash()
	local time = GetTime()
	
	if NextTime < time then
		if MainMenuBarBackpackButton.freeSlots == 0 then
			local bestValue, bestBag, bestSlot
		
			for bag, slot, id in Scrap:IterateJunk() do
				local bagType = select(2, GetContainerNumFreeSlots(bag))
				if not bagType then
					return
				end
				
				if bagType == 0 then
					local maxStack = select(8, GetItemInfo(id))
					local stack = select(2, GetContainerItemInfo(bag, slot))
					if not stack or not maxStack then
						return
					end
					
					local value = select(11, GetItemInfo(id)) * (stack + maxStack) * .5 -- Lets bet 50% on not full stacks
					if not bestValue or value < bestValue then
						bestBag, bestSlot = bag, slot
						bestValue = value
					end
				end
			end
			
			if bestBag and bestSlot then
				PickupContainerItem(bestBag, bestSlot)
				DeleteCursorItem()
				
				NextTime = time + select(3, GetNetStats())
				TimerFrame:SetScript('OnUpdate', nil)
			end
		end
	else
		TimerFrame:SetScript('OnUpdate', CleanTrash)
	end
end

hooksecurefunc('MainMenuBarBackpackButton_UpdateFreeSlots', CleanTrash)